"""Tests for health endpoint."""


async def test_health_endpoint(client):
    """Test that health endpoint returns 200."""
    response = await client.get("/api/v1/health")
    assert response.status_code == 200
    assert response.json() == {"code": 0, "data": {"status": "healthy"}, "message": "Success"}

