import pytest
from httpx import ASGITransport, AsyncClient

from main import create_app


@pytest.fixture
async def client():
    """Create an async test client."""
    async with AsyncClient(
        transport=ASGITransport(app=create_app()),
        base_url="http://test",
    ) as ac:
        yield ac

